# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import rpc_pb2 as rpc__pb2


class MeshStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RegisterToPublish = channel.unary_unary(
        '/rpc.Mesh/RegisterToPublish',
        request_serializer=rpc__pb2.PeerTopicInfo.SerializeToString,
        response_deserializer=rpc__pb2.Response.FromString,
        )
    self.Publish = channel.unary_unary(
        '/rpc.Mesh/Publish',
        request_serializer=rpc__pb2.PublishData.SerializeToString,
        response_deserializer=rpc__pb2.Response.FromString,
        )
    self.Subscribe = channel.unary_stream(
        '/rpc.Mesh/Subscribe',
        request_serializer=rpc__pb2.PeerTopicInfo.SerializeToString,
        response_deserializer=rpc__pb2.Data.FromString,
        )


class MeshServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RegisterToPublish(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Publish(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Subscribe(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MeshServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RegisterToPublish': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterToPublish,
          request_deserializer=rpc__pb2.PeerTopicInfo.FromString,
          response_serializer=rpc__pb2.Response.SerializeToString,
      ),
      'Publish': grpc.unary_unary_rpc_method_handler(
          servicer.Publish,
          request_deserializer=rpc__pb2.PublishData.FromString,
          response_serializer=rpc__pb2.Response.SerializeToString,
      ),
      'Subscribe': grpc.unary_stream_rpc_method_handler(
          servicer.Subscribe,
          request_deserializer=rpc__pb2.PeerTopicInfo.FromString,
          response_serializer=rpc__pb2.Data.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'rpc.Mesh', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import grpc

from .lib.rpc_pb2 import PeerTopicInfo, PublishData, Data
from .lib.rpc_pb2_grpc import MeshStub
from .exp import MeshRPCException
from .util import getTopicsFromGeospace

class MeshRPC:
    def __init__(self, endpoint):
        c = grpc.insecure_channel(endpoint)
        self.stub = MeshStub(c)

    def subscribe(self, channel, geospace):
        topicList = getTopicsFromGeospace(channel, geospace)

        m = PeerTopicInfo()
        m.topics.extend(topicList)
        
        s = self.stub.Subscribe(m)

        return s

    def registerToPublish(self, channel, geospace):
        topicList = getTopicsFromGeospace(channel, geospace)

        m = PeerTopicInfo()
        m.topics.extend(topicList)

        try:
            p = self.stub.RegisterToPublish(m)
            return p
        except grpc.RpcError as e:
            raise MeshRPCException(e.details())

    def publish(self, channel, geospace, raw):
        topicList = getTopicsFromGeospace(channel, geospace)

        pd = PublishData()
        
        pd.info.topics.extend(topicList)
        pd.data.raw = raw

        try:
            res = self.stub.Publish(pd)
            return res
        except grpc.RpcError as e:
            raise MeshRPCException(e.details())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='rpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\trpc.proto\x12\x03rpc\"-\n\rPeerTopicInfo\x12\x0c\n\x04peer\x18\x01 \x01(\t\x12\x0e\n\x06topics\x18\x02 \x03(\t\"H\n\x0bPublishData\x12 \n\x04info\x18\x01 \x01(\x0b\x32\x12.rpc.PeerTopicInfo\x12\x17\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\t.rpc.Data\"\x1b\n\x08Response\x12\x0f\n\x07message\x18\x01 \x01(\t\"\"\n\x04\x44\x61ta\x12\r\n\x05topic\x18\x01 \x03(\t\x12\x0b\n\x03raw\x18\x02 \x01(\x0c\x32\x9e\x01\n\x04Mesh\x12\x38\n\x11RegisterToPublish\x12\x12.rpc.PeerTopicInfo\x1a\r.rpc.Response\"\x00\x12,\n\x07Publish\x12\x10.rpc.PublishData\x1a\r.rpc.Response\"\x00\x12.\n\tSubscribe\x12\x12.rpc.PeerTopicInfo\x1a\t.rpc.Data\"\x00\x30\x01\x62\x06proto3')
)




_PEERTOPICINFO = _descriptor.Descriptor(
  name='PeerTopicInfo',
  full_name='rpc.PeerTopicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='rpc.PeerTopicInfo.peer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topics', full_name='rpc.PeerTopicInfo.topics', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=63,
)


_PUBLISHDATA = _descriptor.Descriptor(
  name='PublishData',
  full_name='rpc.PublishData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rpc.PublishData.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='rpc.PublishData.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=137,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='rpc.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='rpc.Response.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=166,
)


_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='rpc.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='rpc.Data.topic', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw', full_name='rpc.Data.raw', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=202,
)

_PUBLISHDATA.fields_by_name['info'].message_type = _PEERTOPICINFO
_PUBLISHDATA.fields_by_name['data'].message_type = _DATA
DESCRIPTOR.message_types_by_name['PeerTopicInfo'] = _PEERTOPICINFO
DESCRIPTOR.message_types_by_name['PublishData'] = _PUBLISHDATA
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Data'] = _DATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PeerTopicInfo = _reflection.GeneratedProtocolMessageType('PeerTopicInfo', (_message.Message,), {
  'DESCRIPTOR' : _PEERTOPICINFO,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpc.PeerTopicInfo)
  })
_sym_db.RegisterMessage(PeerTopicInfo)

PublishData = _reflection.GeneratedProtocolMessageType('PublishData', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpc.PublishData)
  })
_sym_db.RegisterMessage(PublishData)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpc.Response)
  })
_sym_db.RegisterMessage(Response)

Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
  'DESCRIPTOR' : _DATA,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:rpc.Data)
  })
_sym_db.RegisterMessage(Data)



_MESH = _descriptor.ServiceDescriptor(
  name='Mesh',
  full_name='rpc.Mesh',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=205,
  serialized_end=363,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterToPublish',
    full_name='rpc.Mesh.RegisterToPublish',
    index=0,
    containing_service=None,
    input_type=_PEERTOPICINFO,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Publish',
    full_name='rpc.Mesh.Publish',
    index=1,
    containing_service=None,
    input_type=_PUBLISHDATA,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='rpc.Mesh.Subscribe',
    index=2,
    containing_service=None,
    input_type=_PEERTOPICINFO,
    output_type=_DATA,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MESH)

DESCRIPTOR.services_by_name['Mesh'] = _MESH

# @@protoc_insertion_point(module_scope)



def getTopicsFromGeospace(channel, geospace):
    if isinstance(geospace, str):
        l = [channel + geospace]
        return l
    
    l = []
    for g in geospace:
        l.append(channel + g)
    
    return l